import datetime

from django.template import TemplateSyntaxError, TemplateDoesNotExist, Variable
from django.template import Library, Node
from django.template.loader import get_template, get_template_from_string
from django.conf import settings
from django.utils.safestring import mark_safe

from isd_common.template_loaders import remote

register = Library()

class IncludeRemoteNode(Node):
    def __init__(self, template_name):
        self.template_name = template_name
        try:
            self.load()
        except:
            if settings.TEMPLATE_DEBUG:
                raise
            self.template = None
            self.rtemplate = None

    def load(self):
        if self.template_name in remote.remote_template_uris:
            self.rtemplate = remote.remote_template_uris[self.template_name]
            try:
                source, origin = remote.load_remote_template(self.template_name)
                self.template = get_template_from_string(source, origin, self.template_name)
                return
            except:
                if settings.TEMPLATE_DEBUG:
                    raise
                return # Fail silently for invalid included templates.
        raise TemplateDoesNotExist

    def render(self, context):
        if not self.template or \
        self.rtemplate['expires'] <= datetime.datetime.now():
            self.load()
        return self.template.render(context)

def do_remote(parser, token):
    """
    Loads a remote template and renders it with the current context.

    Example::

        {% include_remote "foo/some_include" %}
    """
    bits = token.split_contents()
    if len(bits) != 2:
        raise TemplateSyntaxError, "%r tag takes one argument: the name of the template to be included" % bits[0]
    path = bits[1]
    if path[0] in ('"', "'") and path[-1] == path[0]:
        return IncludeRemoteNode(path[1:-1])
    return IncludeRemoteNode(bits[1])

register.tag('include_remote', do_remote)
