'''
Profides WSGI Application with OOPS handling for USN website.
'''

import logging
import logging.config
import platform
import traceback

from canonical.oops.serializer import OOPSRFC822Serializer
from canonical.oops.wsgi import OopsWare
from django.core.handlers.wsgi import WSGIHandler
from django.conf import settings

# setup application
def make_app():
    """Encapsulate our Django handler in an OOPS app for error reporting."""
    app = WSGIHandler()
    oops_dir = getattr(settings, 'OOPS_DIR', '/tmp')
    default_id = ''.join(x for x in platform.node() if x.isalpha())
    appserver_id = getattr(settings, 'APPSERVER_ID', default_id)
    logging.config.fileConfig(settings.WEBAPP_LOGGING_CONFIG)
    oops = OopsWare(app, oops_dir=oops_dir, key=appserver_id, hide_meta=False)
    oops.serial = OOPSRFC822Serializer(appserver_id, oops_dir, None)
    return oops
